@@ -10,13 +10,14 @@ use Carp;
 use Raisin;
 use Raisin::Entity;
 
-my @APP_CONF_METHODS = qw(api_default_format api_format api_version middleware mount plugin);
+my @APP_CONF_METHODS = qw(api_default_format api_format api_version middleware
+    mount plugin register_decoder register_encoder);
 my @APP_EXEC_METHODS = qw(new run);
 my @APP_METHODS = qw(req res param include_missing session present error);
 my @HOOKS_METHODS = qw(before before_validation after_validation after);
 my @HTTP_METHODS = qw(del get head options patch post put);
-my @ROUTES_METHODS = qw(resource namespace route_param params requires optional group);
-
+my @ROUTES_METHODS =
+    qw(resource namespace route_param params requires optional group);
 my @SWAGGER_MERTHODS = qw(desc entity summary tags);
 
 our @EXPORT = (
@@ -102,6 +103,19 @@ sub route_param {
     resource(":$param", $code, named => delete $SETTINGS{params});
 }
 
+#
+# Serialization
+#
+sub register_decoder {
+    my ($format, $class) = @_;
+    app->decoder->register($format => $class);
+}
+
+sub register_encoder {
+    my ($format, $class) = @_;
+    app->encoder->register($format => $class);
+}
+
 #
 # Actions
 #
@@ -185,6 +199,7 @@ sub present {
 
 sub include_missing {
     my $p = shift;
+    # TODO: replace app->req->{'raisin.declared'}, if it is possible, to app->route->params
     my %pp = map { $_->name, $p->{ $_->name } } @{ app->req->{'raisin.declared'} };
     \%pp;
 }
@@ -194,8 +209,8 @@ sub include_missing {
 #
 sub plugin { app->load_plugin(@_) }
 
-sub api_default_format { app->api_default_format(@_) }
-sub api_format { app->api_format(@_) }
+sub api_default_format { app->default_format(@_) }
+sub api_format { app->format(@_) }
 
 # TODO:
 # prepend a resource with a version number
@@ -205,7 +220,11 @@ sub api_version { app->api_version(@_) }
 #
 # Render
 #
-sub error { app->res->render_error(@_) }
+sub error {
+    my ($code, $message) = @_;
+    app->res->status($code);
+    app->res->body($message);
+}
 
 1;
 
